*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** Recreating_BLS_Weights.do 
*** Creates Figure 4 (Line 305)

* This code conducts a demographic adjustment of our main results in the paper
* The main results compute labor force metrics using individual counts,
* i.e. not the BLS weights. We introduce a method here to backout the BLS's 
* desired demographic shares and to adjust the raw individual accounts to match
* those demographic shares. This allows us to examine how much of the bias resulting
* from our imputation is controlled for by the BLS's weighting procedure

** Globals
global INDATA  "$IS_dir/Data" 
global OUTDATA  "$IS_dir/Graphs" 

clear
gen date=.

save Data/BLSWeightsFilled, replace


local x = 199802

while `x' <=201912 { 


use Data/cpsb_filledin_flows2_`x'.dta, clear
keep if age>15


*Set up demographic bins
gen agebin=.
replace agebin = 1 if age>=10 &age<30
replace agebin = 2 if age>=30 &age<50
replace agebin = 3 if age>=50 &age<70
replace agebin = 4 if age>=70

gen racebin=.
replace racebin = 1 if race==1
replace racebin = 2 if race>1

gen ResBin=.
replace ResBin=1 if rogue_weight==.
replace ResBin=0 if rogue_weight!=.

*computing raw population shares for only survey responders
bysort agebin sex racebin PEHSPNON gestfips ResBin: egen p_raw=count(PWCMPWGT)
egen sum_p_raw=count(PWCMPWGT) if ResBin==1
*this generates the share of individuals in each demographic bin
gen PopShare_raw=p_raw/sum_p_raw if ResBin==1

*computing BLS weighted population shares for only survey responders
bysort agebin sex racebin PEHSPNON gestfips ResBin: egen p_BLS=total(PWCMPWGT)
egen sum_p_BLS=total(PWCMPWGT) if ResBin==1
*this generates the share of weighted individuals in each demographic bin
*We treat this as our target since it is constructed from BLS weights, it should
*reflect the BLS's desired population share.
gen PopShare_BLS=p_BLS/sum_p_BLS if ResBin==1

gen AdjFactor_raw=PopShare_BLS/PopShare_raw
*EPOP for raw counts of responders
egen EPOP_raw_tmp=mean(employed_flows) if status!=.
egen EPOP_raw = max(EPOP_raw_tmp)
drop EPOP_raw_tmp


*generate LFPR
egen UPOP_raw_tmp=mean(unemployed_flows) if status!=.
egen UPOP_raw = max(UPOP_raw_tmp)
drop UPOP_raw_tmp
gen LFPR_raw=EPOP_raw+UPOP_raw

*generate raw UR
egen U_raw=total(unemployed_flows) if status!=.
egen E_raw=total(employed_flows) if status!=.
gen UR_raw_tmp=U_raw/(U_raw+E_raw)
egen UR_raw=max(UR_raw_tmp)
drop UR_raw_tmp

*Compute the headline BLS EPOP and LFPR and UR
egen E_BLS_tmp=total(PWCMPWGT) if employed_flows==1
egen E_BLS=max(E_BLS_tmp)
drop E_BLS_tmp
*nobody who is imputed in has employed flows=1 so this is just the headline series
gen EPOP_BLS_tmp=E_BLS/sum_p_BLS
*Headline EPOP
egen EPOP_BLS=max(EPOP_BLS_tmp)
drop EPOP_BLS_tmp

egen U_BLS_tmp=total(PWCMPWGT) if unemployed_flows==1
egen U_BLS=max(U_BLS_tmp)
drop U_BLS_tmp

gen UPOP_BLS_tmp=U_BLS/sum_p_BLS
egen UPOP_BLS=max(UPOP_BLS_tmp)
drop UPOP_BLS_tmp

*Headline LFPR
gen LFPR_BLS=EPOP_BLS+UPOP_BLS

*Headline UR
gen UR_BLS=U_BLS/(U_BLS+E_BLS)

*demographically adjust the non-imputed data. This should give labor market indicators
*that are relatively close to the headline ones
gen employed_raw_Adj=employed_flows*AdjFactor_raw if ResBin==1
*This is raw counts, but not imputed, quasi BLS demopgraphic adjustment
egen E_raw_Adj_tmp=total(employed_raw_Adj) if ResBin==1
egen E_raw_Adj=max(E_raw_Adj_tmp)
drop E_raw_Adj_tmp

gen unemployed_raw_Adj=unemployed_flows*AdjFactor_raw if ResBin==1
*This is raw counts, but not imputed, quasi BLS demopgraphic adjustment
egen U_raw_Adj_tmp=total(unemployed_raw_Adj) if ResBin==1
egen U_raw_Adj=max(U_raw_Adj_tmp)
drop U_raw_Adj_tmp

egen pop_raw_Adj_tmp=total(AdjFactor_raw) if ResBin==1
egen pop_raw_Adj=max(pop_raw_Adj_tmp)
drop pop_raw_Adj_tmp

*quasi demographically adjusted EPOP
gen EPOP_raw_Adj=E_raw_Adj/pop_raw_Adj

*quasi demographically adjusted LFPR
gen LFPR_raw_Adj=(E_raw_Adj+U_raw_Adj)/pop_raw_Adj

*quasi demographically adjusted LFPR
gen UR_raw_Adj=(U_raw_Adj)/(E_raw_Adj+U_raw_Adj)

*computes demographic shares of responders + flows filled in and Rogue weighted
gen person_indicator = 1 if PWCMPWGT>0
replace person_indicator=rogue_weight if rogue_weight!=.
bysort agebin sex racebin PEHSPNON gestfips: egen p_imputed=total(person_indicator)
egen sum_p_imputed=total(person_indicator)
gen PopShare_imputed=p_imputed/sum_p_imputed


*Corrected labor force metrics (non demographically adjusted)
*EPOP for flow filled in and rogue weighted (full adjustment)

gen employed_flows_rw=rogue_weight*employed_flows if missing(status)
replace employed_flows_rw = employed_flows if status!=.
egen E_imputed=total(employed_flows_rw)

gen unemployed_flows_rw=rogue_weight*unemployed_flows if missing(status)
replace unemployed_flows_rw = unemployed_flows if status!=.
egen U_imputed=total(unemployed_flows_rw)

gen EPOP_imputed=E_imputed/sum_p_imputed
gen LFPR_imputed=(U_imputed+E_imputed)/sum_p_imputed
gen UR_imputed=(U_imputed)/(U_imputed+E_imputed)


*Compute erroneous imputed series using CPS weights
gen employed_flows_rw_BLS=PWCMPWGT*employed_flows_rw
egen E_imputed_BLS=total(employed_flows_rw_BLS)
gen unemployed_flows_rw_BLS=PWCMPWGT*unemployed_flows_rw
egen U_imputed_BLS=total(unemployed_flows_rw_BLS)

gen PWCMPWGT_imputed=person_indicator*PWCMPWGT

egen sum_p_imputed_BLS=total(PWCMPWGT_imputed)

gen EPOP_imputed_BLS=E_imputed_BLS/sum_p_imputed_BLS
gen LFPR_imputed_BLS=(E_imputed_BLS+U_imputed_BLS)/sum_p_imputed_BLS
gen UR_imputed_BLS=U_imputed_BLS/(E_imputed_BLS+U_imputed_BLS)


*fill in backward engineered BLS demographic shares to compare against our filled in data Raw shares
bysort agebin sex racebin PEHSPNON gestfips: egen PopShare_imputed_BLS=mean(PopShare_BLS)

*essentially this is looking at how the demographic shares of responders+filled in folks look relative to BLS targets
*if this =1, our filling in procedure if perfectly correlated with demographic adjustment
gen AdjFactor_imputed=PopShare_imputed_BLS/PopShare_imputed
replace AdjFactor_imputed=1 if AdjFactor_imputed==.


gen employed_imputed_Adj=employed_flows_rw*AdjFactor_imputed
gen unemployed_imputed_Adj=unemployed_flows_rw*AdjFactor_imputed
gen person_indicator_Adj=person_indicator*AdjFactor_imputed
egen sum_p_imputed_Adj=total(person_indicator_Adj)

*Full imputation and demographically adjust LF indicators
egen E_imputed_Adj=total(employed_imputed_Adj)
egen U_imputed_Adj=total(unemployed_imputed_Adj)
gen EPOP_imputed_Adj=E_imputed_Adj/sum_p_imputed_Adj
gen LFPR_imputed_Adj=(E_imputed_Adj+U_imputed_Adj)/sum_p_imputed_Adj
gen UR_imputed_Adj=U_imputed_Adj/(U_imputed_Adj+E_imputed_Adj)


gen id=_n

keep if id==1

keep EPOP* LFPR* UR*

gen date = `x' 


append using Data/BLSWeightsFilled	

save Data/BLSWeightsFilled, replace 

local x = `x' + 1
if (`x'-13)/100 == int((`x'-13)/100) {
    local x = `x' + 88
    }
	
}


*opening data
use "$INDATA/BLSWeightsFilled", clear

drop if date==.

sort date
gen mdate=m(1998m2)+_n-1
tsset mdate, m

global LFNAMES "EPOP LFPR UR"

foreach state in $LFNAMES{

tssmooth ma `state'_raw_ma= `state'_raw, window(11 1)
tssmooth ma `state'_BLS_ma= `state'_BLS, window(11 1)
tssmooth ma `state'_raw_Adj_ma= `state'_raw_Adj, window(11 1)
tssmooth ma `state'_imputed_ma= `state'_imputed, window(11 1)
tssmooth ma `state'_imputed_Adj_ma= `state'_imputed_Adj, window(11 1)
tssmooth ma `state'_imputed_BLS_ma= `state'_imputed_BLS, window(11 1)

gen Diff_`state'_baseline=`state'_imputed_ma-`state'_raw_ma
gen Diff_`state'_baseline_Adj=`state'_imputed_Adj_ma-`state'_raw_Adj_ma
gen Diff_`state'_BLS=`state'_imputed_BLS_ma-`state'_BLS_ma

**Converting to percentage points 

gen Diff_`state'_baseline_pp=Diff_`state'_baseline*100
gen Diff_`state'_baseline_Adj_pp=Diff_`state'_baseline_Adj*100
gen Diff_`state'_BLS_pp=Diff_`state'_BLS*100

}

** Useful statistics
gen change_baseline_Adj = 100*(Diff_LFPR_baseline_Adj[263] - Diff_LFPR_baseline_Adj[1])
gen change_baseline = 100*(Diff_LFPR_baseline[263] - Diff_LFPR_baseline[1])
gen ratio_change = change_baseline_Adj/change_baseline 

** Bias contributing to the decline in LFPR since 2000
gen change_raw_Adj_2000 = LFPR_raw_Adj[263] - LFPR_raw_Adj[24]
gen change_baseline_Adj_2000 = LFPR_imputed_Adj[263] - LFPR_imputed_Adj[24]
gen percent_change_2000 = 100 - 100*(change_baseline_Adj_2000/change_raw_Adj_2000)

** Graphing
set scheme s2color

** Sample--triming first 12 months because of 12-month historical average
drop if date<199901

**LFPR Gaps
line Diff_LFPR_baseline_pp Diff_LFPR_baseline_Adj_pp Diff_LFPR_BLS_pp mdate, ///
lcolor("black" "blue" "green") lpattern("_" "l" "-.") ///
ytitle("Percentage Points ") ylabel(-.2 (.2) 1.3,angle(0)) yscale(range(-.2 1.4)) ///
xtitle(" ") tlabel(2000m1 (60) 2020m1) xla(,ang(0)) ///
leg(off) ///
subtitle("Labor Force Participation Rate", ring(0) pos(1) nobexpand size(medsmall)) ///
graphregion(color(white)) bgcolor(white) 
graph save "${OUTDATA}/DemAdjCorr_LF.gph" , replace 

*EPOP Gaps
line Diff_EPOP_baseline_pp Diff_EPOP_baseline_Adj_pp Diff_EPOP_BLS_pp mdate, ///
lcolor("black" "blue" "green") lpattern("_" "l" "-.") ///
ytitle("Percentage Points ") ylabel(-0.2 (0.2) 1.3,angle(0)) yscale(range(-0.2 1.4))  ///
xtitle(" ") tlabel(2000m1 (60) 2020m1) xla(,ang(0)) ///
subtitle("Employment-Population Ratio", ring(0) pos(1) nobexpand size(medsmall)) ///
leg(off) ///
graphregion(color(white)) bgcolor(white)
graph save "${OUTDATA}/DemAdjCorr_EP.gph" , replace 

*UR Gaps
line Diff_UR_baseline_pp Diff_UR_baseline_Adj_pp Diff_UR_BLS_pp mdate, ///
lcolor("black" "blue" "green") lpattern("_" "l" "-.") ///
ytitle("Percentage Points ") xtitle(" ") ylabel(-.2 (.2) 1.3,angle(0)) yscale(range(-.2 1.4)) ///
subtitle("Unemployment Rate", ring(0) pos(1) nobexpand size(medsmall)) ///
legend(order( 1 "Not Demographically Adjusted" 2 "Demographically Adjusted" 3 "BLS Weights Applied Incorrectly") position(9) ring(0) cols(1) region(fcolor(none) lstyle(none))) ///
graphregion(color(white)) bgcolor(white)
graph save "${OUTDATA}/DemAdjCorr_U.gph" , replace 

*Combining Correction Gaps Graphs (Figure 4)
graph combine  ///
	"${OUTDATA}/DemAdjCorr_LF.gph" "${OUTDATA}/DemAdjCorr_EP.gph" /// 
	"${OUTDATA}/DemAdjCorr_U.gph", rows(3) ysize(8) 
graph export "${OUTDATA}/Fig4_combined.eps", replace 


